pub trait ContentSource:
Send
+ Sync
+ NonLocalValue
+ ValueDebug {
// Required method
fn get_routes(self: Vc<Self>) -> Vc<RouteTree>
where Self: Sized;
// Provided method
fn get_children(self: Vc<Self>) -> Vc<ContentSources>
where Self: Sized { ... }
}Expand description
A source of content that the dev server uses to respond to http requests.
Required Methods
Provided Methods
Sourcefn get_children(self: Vc<Self>) -> Vc<ContentSources>where
Self: Sized,
fn get_children(self: Vc<Self>) -> Vc<ContentSources>where
Self: Sized,
Gets any content sources wrapped in this content source.