pub trait ContentSourceSideEffect:
Send
+ Sync
+ NonLocalValue
+ ValueDebug {
// Required method
fn apply(self: Vc<Self>) -> Vc<Completion>
where Self: Sized;
}Expand description
This trait can be emitted as collectible and will be applied after the request is handled and it’s ensured that it finishes before the next request is handled.
Required Methods