ContentSourceSideEffect

Trait ContentSourceSideEffect 

pub trait ContentSourceSideEffect:
    Send
    + Sync
    + NonLocalValue
    + ValueDebug {
    // Required method
    fn apply(self: Vc<Self>) -> Vc<Completion>
       where Self: Sized;
}
This trait can be emitted as collectible and will be applied after the request is handled and it’s ensured that it finishes before the next request is handled.

Required Methods

fn apply(self: Vc<Self>) -> Vc<Completion>
where Self: Sized,